"""
The anatomical location at which two or more bones make contact.

https://schema.org/Joint
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class JointInheritedProperties(TypedDict):
    """The anatomical location at which two or more bones make contact.

    References:
        https://schema.org/Joint
    Note:
        Model Depth 4
    Attributes:
        connectedTo: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Other anatomical structures to which this structure is connected.
        partOfSystem: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The anatomical or organ system that this structure is part of.
        associatedPathophysiology: (Optional[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]): If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
        bodyLocation: (Optional[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]): Location in the body of the anatomical structure.
        relatedTherapy: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A medical therapy related to this anatomy.
        subStructure: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Component (sub-)structure(s) that comprise this anatomical structure.
        relatedCondition: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A medical condition associated with this anatomy.
        diagram: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): An image containing a diagram that illustrates the structure and/or its component substructures and/or connections with other structures.
    """

    connectedTo: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    partOfSystem: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    associatedPathophysiology: NotRequired[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]
    bodyLocation: NotRequired[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]
    relatedTherapy: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    subStructure: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    relatedCondition: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    diagram: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    


class JointProperties(TypedDict):
    """The anatomical location at which two or more bones make contact.

    References:
        https://schema.org/Joint
    Note:
        Model Depth 4
    Attributes:
        structuralClass: (Optional[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]): The name given to how bone physically connects to each other.
        functionalClass: (Optional[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]): The degree of mobility the joint allows.
        biomechnicalClass: (Optional[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]): The biomechanical properties of the bone.
    """

    structuralClass: NotRequired[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]
    functionalClass: NotRequired[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]
    biomechnicalClass: NotRequired[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]
    

#JointInheritedPropertiesTd = JointInheritedProperties()
#JointPropertiesTd = JointProperties()


class AllProperties(JointInheritedProperties , JointProperties, TypedDict):
    pass


def create_schema_org_model(type_: Union[JointProperties, JointInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "Joint"
    return model
    

Joint = create_schema_org_model()