"""
A complex mathematical calculation requiring an online calculator, used to assess prognosis. Note: use the url property of Thing to record any URLs for online calculators.

https://schema.org/MedicalRiskCalculator
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class MedicalRiskCalculatorInheritedProperties(TypedDict):
    """A complex mathematical calculation requiring an online calculator, used to assess prognosis. Note: use the url property of Thing to record any URLs for online calculators.

    References:
        https://schema.org/MedicalRiskCalculator
    Note:
        Model Depth 4
    Attributes:
        estimatesRiskOf: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The condition, complication, or symptom whose risk is being estimated.
        includedRiskFactor: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A modifiable or non-modifiable risk factor included in the calculation, e.g. age, coexisting condition.
    """

    estimatesRiskOf: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    includedRiskFactor: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    


class MedicalRiskCalculatorProperties(TypedDict):
    """A complex mathematical calculation requiring an online calculator, used to assess prognosis. Note: use the url property of Thing to record any URLs for online calculators.

    References:
        https://schema.org/MedicalRiskCalculator
    Note:
        Model Depth 4
    Attributes:
    """

    

#MedicalRiskCalculatorInheritedPropertiesTd = MedicalRiskCalculatorInheritedProperties()
#MedicalRiskCalculatorPropertiesTd = MedicalRiskCalculatorProperties()


class AllProperties(MedicalRiskCalculatorInheritedProperties , MedicalRiskCalculatorProperties, TypedDict):
    pass


def create_schema_org_model(type_: Union[MedicalRiskCalculatorProperties, MedicalRiskCalculatorInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "MedicalRiskCalculator"
    return model
    

MedicalRiskCalculator = create_schema_org_model()