"""
A MerchantReturnPolicy provides information about product return policies associated with an [[Organization]], [[Product]], or [[Offer]].

https://schema.org/MerchantReturnPolicy
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class MerchantReturnPolicyInheritedProperties(TypedDict):
    """A MerchantReturnPolicy provides information about product return policies associated with an [[Organization]], [[Product]], or [[Offer]].

    References:
        https://schema.org/MerchantReturnPolicy
    Note:
        Model Depth 3
    Attributes:
    """

    


class MerchantReturnPolicyProperties(TypedDict):
    """A MerchantReturnPolicy provides information about product return policies associated with an [[Organization]], [[Product]], or [[Offer]].

    References:
        https://schema.org/MerchantReturnPolicy
    Note:
        Model Depth 3
    Attributes:
        refundType: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A refund type, from an enumerated list.
        customerRemorseReturnFees: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The type of return fees if the product is returned due to customer remorse.
        additionalProperty: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.Note: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.
        itemDefectReturnLabelSource: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The method (from an enumeration) by which the customer obtains a return shipping label for a defect product.
        inStoreReturnsOffered: (Optional[Union[List[Union[StrictBool, SchemaOrgObj, str]], StrictBool, SchemaOrgObj, str]]): Are in-store returns offered? (For more advanced return methods use the [[returnMethod]] property.)
        itemCondition: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer. Also used for product return policies to specify the condition of products accepted for returns.
        restockingFee: (Optional[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]): Use [[MonetaryAmount]] to specify a fixed restocking fee for product returns, or use [[Number]] to specify a percentage of the product price paid by the customer.
        returnPolicyCategory: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Specifies an applicable return policy (from an enumeration).
        returnLabelSource: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The method (from an enumeration) by which the customer obtains a return shipping label for a product returned for any reason.
        applicableCountry: (Optional[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]): A country where a particular merchant return policy applies to, for example the two-letter ISO 3166-1 alpha-2 country code.
        returnMethod: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The type of return method offered, specified from an enumeration.
        returnShippingFeesAmount: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Amount of shipping costs for product returns (for any reason). Applicable when property [[returnFees]] equals [[ReturnShippingFees]].
        itemDefectReturnShippingFeesAmount: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Amount of shipping costs for defect product returns. Applicable when property [[itemDefectReturnFees]] equals [[ReturnShippingFees]].
        returnPolicySeasonalOverride: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): Seasonal override of a return policy.
        customerRemorseReturnShippingFeesAmount: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The amount of shipping costs if a product is returned due to customer remorse. Applicable when property [[customerRemorseReturnFees]] equals [[ReturnShippingFees]].
        returnFees: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The type of return fees for purchased products (for any return reason).
        customerRemorseReturnLabelSource: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The method (from an enumeration) by which the customer obtains a return shipping label for a product returned due to customer remorse.
        merchantReturnLink: (Optional[Union[List[Union[SchemaOrgObj, str, AnyUrl]], SchemaOrgObj, str, AnyUrl]]): Specifies a Web page or service by URL, for product returns.
        itemDefectReturnFees: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The type of return fees for returns of defect products.
        merchantReturnDays: (Optional[Union[List[Union[datetime, str, SchemaOrgObj, int, date]], datetime, str, SchemaOrgObj, int, date]]): Specifies either a fixed return date or the number of days (from the delivery date) that a product can be returned. Used when the [[returnPolicyCategory]] property is specified as [[MerchantReturnFiniteReturnWindow]].
        returnPolicyCountry: (Optional[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]): The country where the product has to be sent to for returns, for example "Ireland" using the [[name]] property of [[Country]]. You can also provide the two-letter [ISO 3166-1 alpha-2 country code](http://en.wikipedia.org/wiki/ISO_3166-1). Note that this can be different from the country where the product was originally shipped from or sent to.
    """

    refundType: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    customerRemorseReturnFees: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    additionalProperty: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    itemDefectReturnLabelSource: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    inStoreReturnsOffered: NotRequired[Union[List[Union[StrictBool, SchemaOrgObj, str]], StrictBool, SchemaOrgObj, str]]
    itemCondition: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    restockingFee: NotRequired[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]
    returnPolicyCategory: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    returnLabelSource: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    applicableCountry: NotRequired[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]
    returnMethod: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    returnShippingFeesAmount: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    itemDefectReturnShippingFeesAmount: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    returnPolicySeasonalOverride: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    customerRemorseReturnShippingFeesAmount: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    returnFees: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    customerRemorseReturnLabelSource: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    merchantReturnLink: NotRequired[Union[List[Union[SchemaOrgObj, str, AnyUrl]], SchemaOrgObj, str, AnyUrl]]
    itemDefectReturnFees: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    merchantReturnDays: NotRequired[Union[List[Union[datetime, str, SchemaOrgObj, int, date]], datetime, str, SchemaOrgObj, int, date]]
    returnPolicyCountry: NotRequired[Union[List[Union[str, SchemaOrgObj]], str, SchemaOrgObj]]
    

#MerchantReturnPolicyInheritedPropertiesTd = MerchantReturnPolicyInheritedProperties()
#MerchantReturnPolicyPropertiesTd = MerchantReturnPolicyProperties()


class AllProperties(MerchantReturnPolicyInheritedProperties , MerchantReturnPolicyProperties, TypedDict):
    pass


def create_schema_org_model(type_: Union[MerchantReturnPolicyProperties, MerchantReturnPolicyInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "MerchantReturnPolicy"
    return model
    

MerchantReturnPolicy = create_schema_org_model()