"""
A structured value providing information about the opening hours of a place or a certain service inside a place.The place is __open__ if the [[opens]] property is specified, and __closed__ otherwise.If the value for the [[closes]] property is less than the value for the [[opens]] property then the hour range is assumed to span over the next day.      

https://schema.org/OpeningHoursSpecification
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class OpeningHoursSpecificationInheritedProperties(TypedDict):
    """A structured value providing information about the opening hours of a place or a certain service inside a place.The place is __open__ if the [[opens]] property is specified, and __closed__ otherwise.If the value for the [[closes]] property is less than the value for the [[opens]] property then the hour range is assumed to span over the next day.      

    References:
        https://schema.org/OpeningHoursSpecification
    Note:
        Model Depth 4
    Attributes:
    """

    


class OpeningHoursSpecificationProperties(TypedDict):
    """A structured value providing information about the opening hours of a place or a certain service inside a place.The place is __open__ if the [[opens]] property is specified, and __closed__ otherwise.If the value for the [[closes]] property is less than the value for the [[opens]] property then the hour range is assumed to span over the next day.      

    References:
        https://schema.org/OpeningHoursSpecification
    Note:
        Model Depth 4
    Attributes:
        closes: (Optional[Union[List[Union[datetime, SchemaOrgObj, str]], datetime, SchemaOrgObj, str]]): The closing hour of the place or service on the given day(s) of the week.
        validThrough: (Optional[Union[List[Union[datetime, SchemaOrgObj, str, date]], datetime, SchemaOrgObj, str, date]]): The date after when the item is not valid. For example the end of an offer, salary period, or a period of opening hours.
        opens: (Optional[Union[List[Union[datetime, SchemaOrgObj, str]], datetime, SchemaOrgObj, str]]): The opening hour of the place or service on the given day(s) of the week.
        validFrom: (Optional[Union[List[Union[datetime, SchemaOrgObj, str, date]], datetime, SchemaOrgObj, str, date]]): The date when the item becomes valid.
        dayOfWeek: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The day of the week for which these opening hours are valid.
    """

    closes: NotRequired[Union[List[Union[datetime, SchemaOrgObj, str]], datetime, SchemaOrgObj, str]]
    validThrough: NotRequired[Union[List[Union[datetime, SchemaOrgObj, str, date]], datetime, SchemaOrgObj, str, date]]
    opens: NotRequired[Union[List[Union[datetime, SchemaOrgObj, str]], datetime, SchemaOrgObj, str]]
    validFrom: NotRequired[Union[List[Union[datetime, SchemaOrgObj, str, date]], datetime, SchemaOrgObj, str, date]]
    dayOfWeek: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    

#OpeningHoursSpecificationInheritedPropertiesTd = OpeningHoursSpecificationInheritedProperties()
#OpeningHoursSpecificationPropertiesTd = OpeningHoursSpecificationProperties()


class AllProperties(OpeningHoursSpecificationInheritedProperties , OpeningHoursSpecificationProperties, TypedDict):
    pass


def create_schema_org_model(type_: Union[OpeningHoursSpecificationProperties, OpeningHoursSpecificationInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "OpeningHoursSpecification"
    return model
    

OpeningHoursSpecification = create_schema_org_model()