"""
A structured value representing repayment.

https://schema.org/RepaymentSpecification
"""

from typing import *
from typing_extensions import TypedDict, NotRequired
from pydantic import *
from datetime import *
from time import *


from schorg.schema_org_obj import SchemaOrgObj, SchemaOrgBase


class RepaymentSpecificationInheritedProperties(TypedDict):
    """A structured value representing repayment.

    References:
        https://schema.org/RepaymentSpecification
    Note:
        Model Depth 4
    Attributes:
    """

    


class RepaymentSpecificationProperties(TypedDict):
    """A structured value representing repayment.

    References:
        https://schema.org/RepaymentSpecification
    Note:
        Model Depth 4
    Attributes:
        loanPaymentAmount: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The amount of money to pay in a single payment.
        earlyPrepaymentPenalty: (Optional[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]): The amount to be paid as a penalty in the event of early payment of the loan.
        numberOfLoanPayments: (Optional[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]): The number of payments contractually required at origination to repay the loan. For monthly paying loans this is the number of months from the contractual first payment date to the maturity date.
        loanPaymentFrequency: (Optional[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]): Frequency of payments due, i.e. number of months between payments. This is defined as a frequency, i.e. the reciprocal of a period of time.
        downPayment: (Optional[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]): a type of payment made in cash during the onset of the purchase of an expensive good/service. The payment typically represents only a percentage of the full purchase price.
    """

    loanPaymentAmount: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    earlyPrepaymentPenalty: NotRequired[Union[List[Union[SchemaOrgObj, str]], SchemaOrgObj, str]]
    numberOfLoanPayments: NotRequired[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]
    loanPaymentFrequency: NotRequired[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]
    downPayment: NotRequired[Union[List[Union[SchemaOrgObj, str, StrictInt, StrictFloat]], SchemaOrgObj, str, StrictInt, StrictFloat]]
    

#RepaymentSpecificationInheritedPropertiesTd = RepaymentSpecificationInheritedProperties()
#RepaymentSpecificationPropertiesTd = RepaymentSpecificationProperties()


class AllProperties(RepaymentSpecificationInheritedProperties , RepaymentSpecificationProperties, TypedDict):
    pass


def create_schema_org_model(type_: Union[RepaymentSpecificationProperties, RepaymentSpecificationInheritedProperties, AllProperties] = AllProperties) -> Type[SchemaOrgBase]:
    model = create_model_from_typeddict(type_, __base__=SchemaOrgBase)
    model.__name__ = "RepaymentSpecification"
    return model
    

RepaymentSpecification = create_schema_org_model()